Changelog
=========


0.2 (2022-08-31)
----------------

- Update PM sendable annexes type
  [fngaha]
- Fixed shift of PST structure in detailed description
  [fngaha]


0.1 (2019-06-23)
----------------

- Initial release.
  [sgeulette]

